@@ -34,6 +34,4 @@ def to_coordinates(atoms):
     return atoms[['x_coord', 'y_coord', 'z_coord']].to_numpy()
 
 
-
-
-pass
+DEFAULT_EXCLUDED_ATOMS = 'H|W|CL|CLA|NA|SOD|K'
